$title	Generate Summary Indices for a GTAP6 Baseline

$include gtap6.map

set scn /ref,high,low/;

set	t /1990*2050/,
	tmdl(t) /1990,2001,2005,2010,2015,2020,2025,2030,2035,2040,2045,2050/;

parameter yr(t); yr(t) = 2000 + ord(t);

table fig17(t,scn)   World Oil Prices in Three Cases
	ref	high	low
2001	28.6	28.6	28.6
2005	56.8	56.8	56.8
2010	57.5	69.2	49.2
2015	49.9	79.6	34.0
2020	52.0	89.1	34.1
2025	56.4	94.4	34.9
2030	59.1	100.1	35.7;

*	Assume that the oil price trends to a steady-state value over time:

fig17("2035",scn) = fig17("2030",scn) * (fig17("2030",scn)/fig17("2025",scn))**1;
fig17("2040",scn) = fig17("2035",scn) * (fig17("2030",scn)/fig17("2025",scn))**0.5;
fig17("2045",scn) = fig17("2040",scn) * (fig17("2030",scn)/fig17("2025",scn))**0.25;
fig17("2050",scn) = fig17("2045",scn) * (fig17("2030",scn)/fig17("2025",scn))**0.1;

$setglobal domain tmdl
$setglobal labels tmdl
$setglobal xvalue yr
$libinclude plot fig17

parameter	a(*,*,t)	Reference Growth Path,
		b(*,*,t)	High economic growth path,
		c(*,*,t)	Low Economic Growth Path,
		d(*,*,t)	High Oil Price Path
		e(*,*,t)	Low oil price path,
		f(*,*,*,t)	Sectoral demand projections,
		g(*,*,*,t)	World oil market statistics,
		h(*,*,t)	Electricity capacity and generation statistics;

$gdxin ieo2007.gdx
$load a b c d e f g h

parameters 
	ieocarbon(scn,*,r_gtap6,t)	Emissions by fossil fuel (2000=1),
	ieogdp(scn,r_gtap6,t)		Gross domestic product (2000=1),
	ieocrude(scn,r_gtap6,t)		Crude oil production (2000=1),
	ieoprice(scn,t)			Crude oil price (2000=1);

ieocarbon("ref","oil",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), a("co2liquids",r_eieo,t));
ieocarbon("ref","gas",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), a("co2gas",r_eieo,t));
ieocarbon("ref","col",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), a("co2col",r_eieo,t));

ieocarbon("high","oil",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), b("co2liquids",r_eieo,t));
ieocarbon("high","gas",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), b("co2gas",r_eieo,t));
ieocarbon("high","col",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), b("co2col",r_eieo,t));

ieocarbon("low","oil",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), c("co2liquids",r_eieo,t));
ieocarbon("low","gas",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), c("co2gas",r_eieo,t));
ieocarbon("low","col",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), c("co2col",r_eieo,t));

ieogdp("ref",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), a("gdp",r_eieo,t));
ieogdp("high",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), b("gdp",r_eieo,t));
ieogdp("low",r_gtap6,t) = sum(rmap_e(r_gtap6,r_eieo), c("gdp",r_eieo,t));

ieocrude(scn,r_gtap6,t) = sum(rmap_o(r_gtap6,r_oieo), g(scn,r_oieo,"total",t));

ieoprice(scn,t) = fig17(t,scn) / fig17("2001",scn);

set ff /oil,gas,col/;

ieocarbon(scn,ff,r_gtap6,t)$ieocarbon(scn,ff,r_gtap6,t) = ieocarbon(scn,ff,r_gtap6,t)/ieocarbon(scn,ff,r_gtap6,"1990");
ieogdp(scn,r_gtap6,t)$ieogdp(scn,r_gtap6,t) = ieogdp(scn,r_gtap6,t)/ieogdp(scn,r_gtap6,"1990");
ieocrude(scn,r_gtap6,t)$ieocrude(scn,r_gtap6,t) = ieocrude(scn,r_gtap6,t)/ieocrude(scn,r_gtap6,"2001");
ieoprice(scn,t) = ieoprice(scn,t)/ieoprice(scn,"2001");

set rplot(r_gtap6) /can,usa,chn,aus,jpn/;
parameter	carbon		Baseline carbon emissions index (1990=1);
carbon(scn,tmdl,rplot) = sum(ff,ieocarbon(scn,ff,rplot,tmdl));
display carbon;

execute_unload 'ieo07gtap6.gdx', ieocarbon, ieocrude, ieogdp, ieoprice;
