$title	Read the IEO 2007 Appendix B Workbook (high economic growth case) 

$include layout

set	yr /1990,2003,2004,2010,2015,2020,2025,2030/,
	yrmap(n,yr) /2.1990, 3.2003, 4.2004, 5.2010, 6.2015, 7.2020, 8.2025, 9.2030 /;

set droprow(n)/5/, dropcol(n)/10/;

parameter
	b1(*,*)		"Total Energy Consumption by Region, High Economic Growth Case (Quadrillion Btu)",
	b2(*,*,*)	"Total Energy Consumption by Region and Fuel, High Economic Growth Case (Quadrillion Btu)",
	b3(*,*)		"Gross Domestic Product (GDP) by Region, High Economic Growth Case (Billion 2000 Dollars)",
	b4(*,*)		"Liquids Consumption by Region, High Economic Growth Case (Million Barrels per Day)",
	b5(*,*)		"Natural Gas Consumption by Region, High Economic Growth Case (Trillion Cubic Feet)",
	b6(*,*)		"Coal Consumption by Region, High Economic Growth Case (Million Short Tons)",
	b7(*,*)		"Nuclear Energy Consumption by Region, High Economic Growth Case (Billion Kilowatthours)",
	b8(*,*)		"Consumption of Hydroelectricity and Other Renewable Energy by Region, High Economic Growth Case (Quadrillion Btu)"
	b9(*,*)		"Carbon Dioxide Emissions by Region, High Economic Growth Case (Million Metric Tons Carbon Dioxide)",
	b10(*,*)	"Carbon Dioxide Emissions from Liquids Use by Region, High Economic Growth Case (Million Metric Tons Carbon Dioxide)",
	b11(*,*)	"Carbon Dioxide Emissions from Natural Gas Use by Region, High Economic Growth Case (Million Metric Tons Carbon Dioxide)",
	b12(*,*)	"Carbon Dioxide Emissions from Coal Use by Region, High Economic Growth Case (Million Metric Tons Carbon Dioxide)";
	
$offlisting
$include appendixb.gms
$onlisting

loop(yrmap(nn,yr),

	loop(enmap(n,r,en),
	  b2(r,en,yr) = ws2(n,nn);  ws2(n,nn) = 0;
	);

	loop(rgmap(n,r),
	  b1(r,yr) = ws1(n,nn); ws1(n,nn) = 0;
	  b3(r,yr) = ws3(n,nn); ws3(n,nn) = 0;
	  b4(r,yr) = ws4(n,nn); ws4(n,nn) = 0;
	  b5(r,yr) = ws5(n,nn); ws5(n,nn) = 0;
	  b6(r,yr) = ws6(n,nn); ws6(n,nn) = 0;
	  b7(r,yr) = ws7(n,nn); ws7(n,nn) = 0;
	  b8(r,yr) = ws8(n,nn); ws8(n,nn) = 0;
	  b9(r,yr) = ws9(n,nn); ws9(n,nn) = 0;
	  b10(r,yr) = ws10(n,nn); ws10(n,nn) = 0;
	  b11(r,yr) = ws11(n,nn); ws11(n,nn) = 0;
	  b12(r,yr) = ws12(n,nn); ws12(n,nn) = 0;
	);

);

*	Verify that we have not left any data unread:

ws1(droprow,n) = 0; ws1(n,dropcol) = 0;	abort$card(ws1)	"Nonzeros were not all processed in ws1",ws1;
ws2(droprow,n) = 0; ws2(n,dropcol) = 0;	abort$card(ws2)	"Nonzeros were not all processed in ws2",ws2;
ws3(droprow,n) = 0; ws3(n,dropcol) = 0;	abort$card(ws3)	"Nonzeros were not all processed in ws3",ws3;
ws4(droprow,n) = 0; ws4(n,dropcol) = 0;	abort$card(ws4)	"Nonzeros were not all processed in ws4",ws4;
ws5(droprow,n) = 0; ws5(n,dropcol) = 0;	abort$card(ws5)	"Nonzeros were not all processed in ws5",ws5;
ws6(droprow,n) = 0; ws6(n,dropcol) = 0;	abort$card(ws6)	"Nonzeros were not all processed in ws6",ws6;
ws7(droprow,n) = 0; ws7(n,dropcol) = 0;	abort$card(ws7)	"Nonzeros were not all processed in ws7",ws7;
ws8(droprow,n) = 0; ws8(n,dropcol) = 0;	abort$card(ws8)	"Nonzeros were not all processed in ws8",ws8;
ws9(droprow,n) = 0; ws9(n,dropcol) = 0;	abort$card(ws9)	"Nonzeros were not all processed in ws9",ws9;
ws10(droprow,n) = 0; ws10(n,dropcol) = 0; abort$card(ws10) "Nonzeros were not all processed in ws10",ws10;
ws11(droprow,n) = 0; ws11(n,dropcol) = 0; abort$card(ws11) "Nonzeros were not all processed in ws11",ws11;
ws12(droprow,n) = 0; ws12(n,dropcol) = 0; abort$card(ws12) "Nonzeros were not all processed in ws12",ws12;


$batinclude extrap r b1 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 

set ren(*,*);
ren(r,en) = yes;
$batinclude extrap ren b2

parameter	b(*,r,y)	High Economic Growth Path;
b("energy",r,y) = b1(r,y);
b(r,en,y) = b2(r,en,y);
b("gdp",r,y) = b3(r,y);
b("liquids",r,y) = b4(r,y);
b("gas",r,y) = b5(r,y);
b("col",r,y) = b6(r,y);
b("nuc",r,y) = b7(r,y);
b("renew",r,y) = b8(r,y);
b("co2",r,y) = b9(r,y);
b("co2liquids",r,y) = b10(r,y);
b("co2gas",r,y) = b11(r,y);
b("co2col",r,y) = b12(r,y);

option b:0:2:1;
display b;

