$title	Read the IEO 2007 Appendix E Workbook (low oil price case) 

$include layout

set	yr /1990,2003,2004,2010,2015,2020,2025,2030/,
	yrmap(n,yr) /2.1990, 3.2003, 4.2004, 5.2010, 6.2015, 7.2020, 8.2025, 9.2030 /;

set droprow(n)/5/, dropcol(n)/10/;

parameter
	e1(*,*)		"Total Energy Consumption by Region, Low Oil Price Case (Quadrillion Btu)",
	e2(*,*,*)	"Total Energy Consumption by Region and Fuel, Low Oil Price Case (Quadrillion Btu)",
	e3(*,*)		"Gross Domestic Product (GDP) by Region, Low Oil Price Case (Billion 2000 Dollars)",
	e4(*,*)		"Liquids Consumption by Region, Low Oil Price Case (Million Barrels per Day)",
	e5(*,*)		"Natural Gas Consumption by Region, Low Oil Price Case (Trillion Cubic Feet)",
	e6(*,*)		"Coal Consumption by Region, Low Oil Price Case (Million Short Tons)",
	e7(*,*)		"Nuclear Energy Consumption by Region, Low Oil Price Case (Billion Kilowatthours)",
	e8(*,*)		"Consumption of Hydroelectricity and Other Renewable Energy by Region, Low Oil Price Case (Quadrillion Btu)"
	e9(*,*)		"Carbon Dioxide Emissions by Region, Low Oil Price Case (Million Metric Tons Carbon Dioxide)",
	e10(*,*)	"Carbon Dioxide Emissions from Liquids Use by Region, Low Oil Price Case (Million Metric Tons Carbon Dioxide)",
	e11(*,*)	"Carbon Dioxide Emissions from Natural Gas Use by Region, Low Oil Price Case (Million Metric Tons Carbon Dioxide)",
	e12(*,*)	"Carbon Dioxide Emissions from Coal Use by Region, Low Oil Price Case (Million Metric Tons Carbon Dioxide)";
	
$offlisting
$include appendixd.gms
$onlisting

loop(yrmap(nn,yr),

	loop(enmap(n,r,en),
	  e2(r,en,yr) = ws2(n,nn); ws2(n,nn) = 0;
	);

	loop(rgmap(n,r),
	  e1(r,yr) = ws1(n,nn); ws1(n,nn) = 0;
	  e3(r,yr) = ws3(n,nn); ws3(n,nn) = 0;
	  e4(r,yr) = ws4(n,nn); ws4(n,nn) = 0;
	  e5(r,yr) = ws5(n,nn); ws5(n,nn) = 0;
	  e6(r,yr) = ws6(n,nn); ws6(n,nn) = 0;
	  e7(r,yr) = ws7(n,nn); ws7(n,nn) = 0;
	  e8(r,yr) = ws8(n,nn); ws8(n,nn) = 0;
	  e9(r,yr) = ws9(n,nn); ws9(n,nn) = 0;
	  e10(r,yr) = ws10(n,nn); ws10(n,nn) = 0;
	  e11(r,yr) = ws11(n,nn); ws11(n,nn) = 0;
	  e12(r,yr) = ws12(n,nn); ws12(n,nn) = 0;
	);
);

ws1(droprow,n) = 0; ws1(n,dropcol) = 0;	abort$card(ws1)	"Nonzeros were not all processed in ws1";
ws2(droprow,n) = 0; ws2(n,dropcol) = 0;	abort$card(ws2)	"Nonzeros were not all processed in ws2";
ws3(droprow,n) = 0; ws3(n,dropcol) = 0;	abort$card(ws3)	"Nonzeros were not all processed in ws3";
ws4(droprow,n) = 0; ws4(n,dropcol) = 0;	abort$card(ws4)	"Nonzeros were not all processed in ws4";
ws5(droprow,n) = 0; ws5(n,dropcol) = 0;	abort$card(ws5)	"Nonzeros were not all processed in ws5";
ws6(droprow,n) = 0; ws6(n,dropcol) = 0;	abort$card(ws6)	"Nonzeros were not all processed in ws6";
ws7(droprow,n) = 0; ws7(n,dropcol) = 0;	abort$card(ws7)	"Nonzeros were not all processed in ws7";
ws8(droprow,n) = 0; ws8(n,dropcol) = 0;	abort$card(ws8)	"Nonzeros were not all processed in ws8";
ws9(droprow,n) = 0; ws9(n,dropcol) = 0;	abort$card(ws9)	"Nonzeros were not all processed in ws9";
ws10(droprow,n) = 0; ws10(n,dropcol) = 0; abort$card(ws10) "Nonzeros were not all processed in ws10";
ws11(droprow,n) = 0; ws11(n,dropcol) = 0; abort$card(ws11) "Nonzeros were not all processed in ws11";
ws12(droprow,n) = 0; ws12(n,dropcol) = 0; abort$card(ws12) "Nonzeros were not all processed in ws12";

$batinclude extrap r e1 e3 e4 e5 e6 e7 e8 e9 e10 e11 e12 

set ren(*,*);
ren(r,en) = yes;
$batinclude extrap ren e2


parameter	e(*,r,y)	Low oil price path;
e("energy",r,y) = e1(r,y);
e(r,en,y) = e2(r,en,y);
e("gdp",r,y) = e3(r,y);
e("liquids",r,y) = e4(r,y);
e("gas",r,y) = e5(r,y);
e("col",r,y) = e6(r,y);
e("nuc",r,y) = e7(r,y);
e("renew",r,y) = e8(r,y);
e("co2",r,y) = e9(r,y);
e("co2liquids",r,y) = e10(r,y);
e("co2gas",r,y) = e11(r,y);
e("co2col",r,y) = e12(r,y);

option e:0:2:1;
display e;

